**Questions**: feel free to [ask on StackOverflow](https://stackoverflow.com/questions/ask) with
the **zfit** tag (so we also get notified).

**Bugs or Feature Requests** Please fill the below form _if possible_.

<!--- Provide a general summary of the issue in the Title above -->

## Current Behaviour

<!--- Tell us what happens instead of the expected behavior -->
<!--- Include the commands you ran and the output. -->

```
Paste the command(s) you ran and the output.
If there was a crash, please include the traceback here.
```

## Expected Behaviour

<!--- Tell us what should happen. -->

## Context (Environment)

<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

-   zfit version:
-   Python version:
-   Are you using conda, pipenv, etc? :
-   Operating System:
-   Tensorflow version:

## Possible Solution/Implementation

<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- and maybe suggest an idea for implementing addition or change -->
